# ApplicationUpstreamFormInfo

Describes the properties of the form used to submit login information

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**username_field** | **str** | The name of the username field in the login form&#39;s html. This can be determined by inspecting the login page html using a tool like Chrome&#39;s Dev Tools.  | 
**password_field** | **str** | The name of the password field in the login form&#39;s html. This can be determined by inspecting the login page html using a tool like Chrome&#39;s Dev Tools.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


